# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class NominationGateStatus(str, Enum):
    """
    NominationGateStatus
    """

    """
    allowed enum values
    """
    OPEN = 'OPEN'
    CLOSED = 'CLOSED'
    NOT_YET_OPEN = 'NOT_YET_OPEN'
    CANCELLED = 'CANCELLED'

    @classmethod
    def from_json(cls, json_str: str) -> NominationGateStatus:
        """Create an instance of NominationGateStatus from a JSON string"""
        return NominationGateStatus(json.loads(json_str))


