# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class BusinessProcessStepLogicType(str, Enum):
    """
    BusinessProcessStepLogicType
    """

    """
    allowed enum values
    """
    INTERNAL_LOGIC = 'INTERNAL_LOGIC'
    REQUEST_GENERATION = 'REQUEST_GENERATION'
    REQUEST_SENDING = 'REQUEST_SENDING'
    RESPONSE_POLLING = 'RESPONSE_POLLING'
    RESPONSE_PROCESSING = 'RESPONSE_PROCESSING'
    REQUEST_PROCESSING = 'REQUEST_PROCESSING'
    RESPONSE_SENDING = 'RESPONSE_SENDING'

    @classmethod
    def from_json(cls, json_str: str) -> BusinessProcessStepLogicType:
        """Create an instance of BusinessProcessStepLogicType from a JSON string"""
        return BusinessProcessStepLogicType(json.loads(json_str))


